<?php
namespace Folha\Logic\ESocial\Eventos\Data;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-2205 - Alteração de Dados Cadastrais do Trabalhador
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S2205
{

    /**
     * Retorna os dados que serao utilizados para a geracao do(s) arquivo(s) do evento S-2205, Alteração de Dados Cadastrais do Trabalhador.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro apliceado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do
     *                                 ultimo envio.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo,
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo)
    {
        $S2205 = \Folha\Repositories\GpeEsocialRegistro::dataSetEsocial_S2205(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo,
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo
        );

        foreach ($S2205 as &$row) {

            /*Parte criada para setar as chaves pais que não possuem valor, são do tipo G, para que no xml o IF do TWIG reconheça que existem as chaves filhas (elementos)*/
            if (isset($row['NRCTPS']) or isset($row['SERIECTPS']) or isset($row['UFCTPS']) or
                isset($row['NRRG']) or isset($row['RG_ORGAOEMISSOR']) or isset($row['RG_DTEXPED']) or
                isset($row['NRRNE']) or
                isset($row['NRREGCNH']) or isset($row['CNH_DTEXPED']) or isset($row['UFCNH']) or isset($row['CNH_DTVALIDADE']) or isset($row['DTPRIHAB']) or isset($row['CATEGORIACNH'])) {

                $row['DOCUMENTOS'] = '1';

                /*CTPS*/
                if (isset($row['NRCTPS']) or isset($row['SERIECTPS']) or isset($row['UFCTPS'])) {
                    $row['CTPS'] = '1';
                }

                /*RG*/
                if (isset($row['NRRG']) or isset($row['RG_ORGAOEMISSOR']) or isset($row['RG_DTEXPED'])) {
                    $row['RG'] = '1';
                }

                /*RNE*/
                if (isset($row['NRRNE'])) {
                    $row['RNE'] = '1';
                }

                /*CNH*/
                if (isset($row['NRREGCNH']) or isset($row['CNH_DTEXPED']) or isset($row['UFCNH']) or isset($row['CNH_DTVALIDADE']) or isset($row['DTPRIHAB']) or isset($row['CATEGORIACNH'])) {
                    $row['CNH'] = '1';
                }
            }

            /*Aqui são verificados os endereços do empregado - se é do Brasil ou do exterior*/
            if (isset($row['TPLOGRAD'])) {
                $row['BRASIL'] = '1';
            }
            if (isset($row['PAISRESID'])) {
                $row['EXTERIOR'] = '1';
            }

            /*Aqui é verificado se é um trabalhador estrangeiro*/
            if (isset($row['DTCHEGADA'])) {
                $row['TRABESTRANGEIRO'] = '1';
            }

            /*Aqui é verificado se possui deficiência*/
            if ($row['DEFFISICA']=='S' or $row['DEFVISUAL']=='S' or $row['DEFAUDITIVA']=='S' or $row['DEFMENTAL']=='S' or $row['DEFINTELECTUAL']=='S' or $row['REABREADAP']=='S') {
                $row['INFODEFICIENCIA'] = '1';
            }

            /*Aqui são gerados os dependentes do empregado em um sub array no xml o FOR do TWIG possa buscar os dados para cada empregado*/
            $dependentes = \Folha\Repositories\GpeEsocialRegistro::s2100_dependentes($row['NRPARCNEGOCIO'], $nrorg);
            $contDep = 0;
            foreach ($dependentes as &$dependente) {
                $row['DEPENDENTE'][$contDep] =
                    array(
                        "_EVTADMISSAO_TRABALHADOR_DEPENDENTE_TPDEP" => $dependente['TPDEP'],
                        "_EVTADMISSAO_TRABALHADOR_DEPENDENTE_NMDEP" => $dependente['NMPESSOA'],
                        "_EVTADMISSAO_TRABALHADOR_DEPENDENTE_DTNASCTO" => $dependente['DTNASCPESSOA'],
                        "_EVTADMISSAO_TRABALHADOR_DEPENDENTE_CPFDEP" => $dependente['NRCPFPESSOA'],
                        "_EVTADMISSAO_TRABALHADOR_DEPENDENTE_DEPIRRF" => $dependente['DEPIRRF'],
                        "_EVTADMISSAO_TRABALHADOR_DEPENDENTE_DEPSF" => $dependente['DEPSF']);
                $contDep++;
            }

            /*Aqui é verificado se existem informações sobre formas de contato*/
            if (isset($row['FONEPRINC']) or isset($row['FONEALTERNAT']) or isset($row['EMAILPRINC'])) {
                $row['CONTATO'] = '1';
            }
        }

        return $S2205;
    }

}