<?php
/**
 * Classe das variaveis de ambiente.
 * Para exemplo de uso de codigo verifique a Classe "\Geral\Logic\Login"
 *
 * @todo persistir na sessão.
 */

namespace Geral\Util;

use Geral\Entities\Filial;
use Geral\Entities\Operador;
use Setforms2\Runtime\Logger;
use Symfony\Component\Validator\Constraints\DateTime;

class Ambiente
{
    private $nrOrg;
    private $cdOperador;
    private $dsemailoper;
    private $senha;

    /** @var Ambiente */
    private static $instancia = null;
    /** @var $organizacao \Geral\Entities\Organizacao */
    private static $organizacao;
    /** @var Operador */
    private static $operador = null;
    /** @var Filial */
    private static $filial = null;
    private static $estrutura = null;
    /** @var $perfilacesso \Geral\Entities\Perfacessparc*/
    private static $perfilacesso = null;

    private function __construct(\Geral\Logic\Login $login) {
        $this->nrOrg       = $login->getOrganizacao()->getNrorg();
        $this->senha       = $login->getSenha();
        $this->cdOperador  = $login->getOperador()->getCdoperador();
        $this->dsemailoper = $login->getOperador()->getDsemailoper();
    }

    /**
     * @static
     * @return Ambiente
     * @throws \Geral\Exceptions\AmbienteNaoEncontrado
     */
    public static function getInstancia() {
        if(self::$instancia === null) {
            self::$instancia = tk_get_env_var('AMBIENTE');
        }
        return self::$instancia;
    }

    public static function factory(\Geral\Logic\Login $login) {
        self::$instancia    = new self($login);
        tk_set_env_var('AMBIENTE', self::$instancia);
    }

    /**
     * @return Filial
     */
    public function getFilial() {
        if(!self::$filial) {
            self::setFilial($this->getOperador()->getEstruttrab()->getCdintestrutura(), $this->getNrorg());
        }
        return self::$filial;
    }

    /**
     * @return Operador
     */
    public function getOperador() {
        if (self::$operador === null) {
            self::$operador = Operador::findOneByDsemailoper($this->dsemailoper);
        }
        return self::$operador;
    }

    /**
     * @return \Geral\Entities\Organizacao
     */
    public function getOrganizacao()
    {
        if (!self::$organizacao) {
            self::$organizacao = \Geral\Entities\Organizacao::findOneByNrorg($this->nrOrg);
        }
        return self::$organizacao;
    }

    public static function getControleDeAcessoAtivo () 
    {
        $paramgeral = \Geral\Entities\Paramgeral::findOneByNrorg(Ambiente::getInstancia()->getOrganizacao()->getNrorg());
        if (!$paramgeral || $paramgeral->getIdutctrlaces() == 'N') {
            return false;
        }
        return true;
    }

    public static function getEstruturaTrabalho() {
        if (!self::$estrutura) {
            self::$estrutura = Ambiente::getInstancia()->getOperador()->getEstruttrab();
        }
        return self::$estrutura;
    }

    public static function getNrEstruturaTrabalho() {
        if (Ambiente::getInstancia()->getEstruturaTrabalho()) {
            return Ambiente::getInstancia()->getEstruturaTrabalho()->getNrestruturam();
        }
        return null;
    }

    public static function getNomeEstruturaTrabalho() {
        if (Ambiente::getInstancia()->getEstruturaTrabalho()) {
            return Ambiente::getInstancia()->getEstruturaTrabalho()->getNmestruturam();
        }
        return null;
    }


    public function getPerfilAcessoParceiro() {
        if (!self::$perfilacesso) {
            self::$perfilacesso = \Geral\Entities\Perfacessparc::findOneByNrparcnegocioAndNrorg(
                $this->getOperador()->getNrparcnegocio(), $this->getOrganizacao()->getNrorg()
            );
        }
        return self::$perfilacesso;
    }

    public static function getCdOperador() {
        $operador=null;
        $instancia = Ambiente::getInstancia();
        if(is_object($instancia)){
            $operador = $instancia->getOperador();
        }
        if(is_object($operador)){
            return $operador->getCdoperador();
        }
        return null;
    }

    public static function getNmOperador() {
        return Ambiente::getInstancia()->getOperador()->getNmoperador();
    }

    public static function getNmacesso() {
        return Ambiente::getInstancia()->getOperador()->getNmacesso();
    }

    public static function getNrorgoper() {
        $nrorg=null;
        $amb = Ambiente::getInstancia();
        if(is_object($amb)){
            $oper = $amb->getOperador();
            if(isset($oper)){
              $nrorg = $oper->getNrorg();
            }
        }
        else{
            throw new \Exception('Erro ao instanciar operador no ambiente.');
        }

        return $nrorg;
    }

    public static function getNrorg() {
        //@todo Mudar para pegar o nrorg do operador assim que compatibilizar os produtos.
        return Ambiente::getInstancia()->getOrganizacao()->getNrorg();
    }

    public static function getNomeOrg($nrorg) {
        $org = \Geral\Entities\Organizacao::findOneByNrorg($nrorg);
        return $org->getNmorganizacao();

    }

    public static function getNrorgTrabalho() {
        return Ambiente::getInstancia()->getOperador()->getNrorgtrab();
    }

    /*
     * Retorna o idioma de um operador, em formato IETF (e.g. pt_BR, es_ES)
     * */
    public static function getIdiomaOperador(){
        return Ambiente::getInstancia()->getOperador()->getIdiomaFromId();
    }

    public static function getCdEmpresa() {
        return Ambiente::getInstancia()->getFilial()->getEmpresa()->getCdempresa();
    }

    public static function getCdCentralCompras() {
        return Ambiente::getInstancia()->getFilial()->getCentralDeCompras();
    }

    public static function getCdInscEstadual() {
        return Ambiente::getInstancia()->getFilial()->getInscesta()->getCdinscesta();
    }

    public static function getCdInscMunicipal() {
        return Ambiente::getInstancia()->getFilial()->getInscmuni()->getCdinscmuni();
    }

    public static function getCdSerie() {
        return Ambiente::getInstancia()->getFilial()->getCdserie();
    }

    public static function getCdFilial(){
        return Ambiente::getInstancia()->getFilial()->getCdfilial();
    }

    public static function getNmFilial(){
        return Ambiente::getInstancia()->getFilial()->getNmfilial();
    }

    public static function getCdRegiao(){
        return Ambiente::getInstancia()->getFilial()->getRegiao()->getCdregiao();
    }

    public static function getNmprincipalparc() {
        return Ambiente::getInstancia()->getOperador()->getParcnegocio()->getNmprincipalparc();
    }

    public static function getNrParceiroNegocio(){
        return Ambiente::getInstancia()->getOperador()->getParcnegocio()->getNrparcnegocio();
    }

    public static function getWhereByNrorg() {
        return tk_get_current_table().'.NRORG = '.self::getNrorg();
    }

    public static function getModoFilial() {
        return 'N';
    }

    /**
     * @return \Geral\Entities\Organizacaooper
     */
    public static function getOrganizacaoOper() {
        $cdoperador = self::getCdOperador();
        $nrorg = self::getNrorgTrabalho();
        $organizacaoOper = \Geral\Entities\Organizacaooper::getObjectByWhere(
            'NRORGREL = ? AND CDOPERADOR = ?',
            array($nrorg, $cdoperador)
        );
        return $organizacaoOper;
    }

    /**
     *
     * @return bool|string
     */
    public static function getDtmescompetencia() {
        $paramoper=null;
        try{
            $paramoper = \Geral\Entities\GpeParamoper::findOneByNrorgAndCdoperador(self::getNrorgTrabalho(), self::getCdOperador());
        }
        catch(\Exception $e){
            //@todo tratar da forma correta
        }
        if (is_object($paramoper)) {
            $return = $paramoper->getDtmescompetenc();
        } else {
            $return = date("01/m/Y");
        }
        return $return;
    }

    public static function setFilial($cdfilial, $nrorg) {
        self::$filial = Filial::getObject(
            array(
                "cdfilial"  => $cdfilial,
                "nrorg"     => $nrorg,
            )
        );
    }

    /**
     * Facilita o uso de calculo de datas usando funções nativas do php.
     * Uma boa pedida seria depreciar a função TkDateTime que custa caro e oferece quase nada.
     * @return object DateTime
     */
    public static function getCompetenciaAsDate() {
        $data = self::getDtmescompetencia();
        $dt=explode('/',$data);
        return new \DateTime($dt[2].'-'.$dt[1].'-'.$dt[0]);
    }

    /**
     * @param Operador $operador
     * @param \Geral\Entities\Perfacessparc $perfilacesso
     */
    public static function setUserInfo(\Geral\Entities\Operador $operador, $perfilacesso = null)
    {


        $config = \Setforms2\Shared\Config::getInstance();

        $userInfo = new \Setforms2\Runtime\Dto\UserInfo();
        $userInfo->setUsername($operador->getNmoperador());
        $userInfo->setUserId($operador->getCdoperador());
        $userInfo->setProjectName($config->getProjectName());
        $userInfo->setOrganizationId($operador->getNrorg());
        if ($perfilacesso) {
            $userInfo->setUserGroupId($perfilacesso->getNrperfilacesso());
        }

        \Setforms2\Runtime\Framework::getInstance()->setUserInfo($userInfo);
    }

    /**
     * @return mixed
     */
    public function getSenha()
    {
        return $this->senha;
    }

    public static function projectWhereClause() {
        try {
            $where = \Setforms2\Shared\Config::getInstance()->getProjectWhereClause();
        } catch (\Setforms2\Shared\Config\Exception\ConfigPropertyNotFoundException $e) {
            $where = '1=1';
        }
        return $where;
    }

    public static function retornaCaminhoLogoCliente(){
        $url = explode('?',$_SERVER['HTTP_REFERER']);
        $logo = $url[0].'images/logo/'.self::getNrorgoper().'-logo.png';
        return $logo;
    }
}
